@@ -9,16 +9,18 @@ module.exports = function (grunt) {
             helpers: ['lib/helpers/*.js'],
             files: [
                 {
-                    src: 'apps/io.ox/dynamic-theme/register.hbs',
-                    dest: 'build/apps/io.ox/dynamic-theme/register.js'
+                    expand: true,
+                    cwd: 'apps/',
+                    src: '**/*.hbs',
+                    dest: 'build/apps/',
+                    ext: '.js'
                 }
             ]
         }
     });
 
     grunt.registerTask('build',
-        ['copy_build', 'compile_po', 'newer:compile-handlebars', 'newer:concat', 'newer:less']
-    );
+        ['copy_build', 'compile_po', 'newer:compile-handlebars', 'newer:concat', 'newer:less']);
 
     grunt.registerTask('dist:build', 'build a distribution ready version into dist/',
         ['clean', 'build', 'copy_dist', 'uglify']
